API
===

This page contains auto-generated documentation from the bidict source code.

bidict
------

.. automodule:: bidict
   :members:
   :imported-members:
   :member-order: bysource
   :special-members:
   :private-members:
   :show-inheritance:
   :undoc-members:
   :inherited-members:

.. autodata:: bidict.RAISE
.. autodata:: bidict.DROP_OLD
.. autodata:: bidict.DROP_NEW
.. autodata:: bidict.ON_DUP_DEFAULT
.. autodata:: bidict.ON_DUP_RAISE
.. autodata:: bidict.ON_DUP_DROP_OLD


.. autofunction:: bidict._iter._iteritems_mapping_or_iterable
.. autofunction:: bidict._iter._iteritems_args_kw

.. attribute:: __version__

   The version of bidict represented as a string.
